# coding: utf-8

"""
    ORY Keto

    A cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.1
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import ory_keto_client
from ory_keto_client.api.engines_api import EnginesApi  # noqa: E501
from ory_keto_client.rest import ApiException


class TestEnginesApi(unittest.TestCase):
    """EnginesApi unit test stubs"""

    def setUp(self):
        self.api = ory_keto_client.api.engines_api.EnginesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_ory_access_control_policy_role_members(self):
        """Test case for add_ory_access_control_policy_role_members

        Add a member to an ORY Access Control Policy Role  # noqa: E501
        """
        pass

    def test_delete_ory_access_control_policy(self):
        """Test case for delete_ory_access_control_policy

        """
        pass

    def test_delete_ory_access_control_policy_role(self):
        """Test case for delete_ory_access_control_policy_role

        Delete an ORY Access Control Policy Role  # noqa: E501
        """
        pass

    def test_do_ory_access_control_policies_allow(self):
        """Test case for do_ory_access_control_policies_allow

        Check if a request is allowed  # noqa: E501
        """
        pass

    def test_get_ory_access_control_policy(self):
        """Test case for get_ory_access_control_policy

        """
        pass

    def test_get_ory_access_control_policy_role(self):
        """Test case for get_ory_access_control_policy_role

        Get an ORY Access Control Policy Role  # noqa: E501
        """
        pass

    def test_list_ory_access_control_policies(self):
        """Test case for list_ory_access_control_policies

        """
        pass

    def test_list_ory_access_control_policy_roles(self):
        """Test case for list_ory_access_control_policy_roles

        List ORY Access Control Policy Roles  # noqa: E501
        """
        pass

    def test_remove_ory_access_control_policy_role_members(self):
        """Test case for remove_ory_access_control_policy_role_members

        Remove a member from an ORY Access Control Policy Role  # noqa: E501
        """
        pass

    def test_upsert_ory_access_control_policy(self):
        """Test case for upsert_ory_access_control_policy

        """
        pass

    def test_upsert_ory_access_control_policy_role(self):
        """Test case for upsert_ory_access_control_policy_role

        Upsert an ORY Access Control Policy Role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
